==> kube-integration-1.0.11.tgz: package/infra/middleware.js <==
'use strict';

const _                = require('lodash');
const Promise          = require('bluebird');
const logger           = require('cf-logs').Logger("codefresh:infra:middlewares");
const KubeManager      = require('./../lib/kube.manager');
const config           = require('./../config');
const MatchFilter      = require('./../server/helpers/filters').Match;
const kubeEventHandler = require('./kube.manager.event.handler');


function ensureNamespaceId(req, res, next) {
    const result = req.checkQuery('namespaceId', 'Query must have namespaceId').notEmpty();
    const errors = _.get(result, 'validationErrors', []);
    if (_.size(errors) > 0) {
        next(new Error(errors[0].msg));
    } else {
        next();
    }
    return;
}

/**
 * Resolve namespaces from query
 * If query have doesnt have any namespace then first fetch all namespaces related to the cluster
 * @param req
 * @param res
 * @param next
 */
function resolveNamespacesFromQuery(req, res, next) {
    const kube       = req.kubeManager;
    const namespaces = req.query.namespace;

    Promise.resolve()
        .then(() => {
            if (!namespaces) {
                return kube.getNamespaceController()
                    .get()
                    .map(ns => ns.getName());
            }

            if (_.isString(namespaces) && _.includes(namespaces, ',')) {
                return namespaces.split(',');
            }

            if (!_.isArray(namespaces)) {
                return [namespaces];
            }

            return namespaces;
        })
        .then((nss) => {
            req.namespaces = nss;
        })
        .done(next, next);
}

function resolveQueryString(req, res, next) { // jshint ignore:line
    const query   = _.omit(_.get(req, 'query', {}), ['namespace', 'selector', 'omit']);
    const keys    = _.keys(query);
    const filters = [];
    return Promise.map(keys, (key) => {
        const value = query[key];
        filters.push(new MatchFilter(key, value));
    })
        .then(() => {
            req.filters = filters;
        })
        .finally(next, next);
}

function prepareKubeConfig(request, response, next) {
    const clusterConf        = _.get(config, 'cluster');
    const clusterCreds       = _.get(clusterConf, 'credentials', {});
    const headers            = request.headers;
    const clusterInformation = {};
    if (clusterConf.host) {
        logger.info('Using cluster credentials from config file');
        logger.info('Using cluster credentials from config file');
        clusterInformation.credentials = {
            clusterCaCertificate: clusterCreds.clusterCaCertificate,
            serviceAccountToken: clusterCreds.token,

        };
        clusterInformation.host        = clusterConf.host;
        clusterInformation.protocol    = clusterConf.protocol
    } else {
        logger.info('Using cluster from headers');
        const clusterData = JSON.parse(headers['x-cluster-data-json']);
        const authType    = _.get(clusterData, 'type');
        // temporary here, should be handled more nicely
        if (authType) {
            if (authType === 'sat') {
                _.set(clusterData, 'ca', Buffer.from(clusterData.ca, 'base64'));
                _.set(clusterData, 'auth.bearer', Buffer.from(clusterData.auth.bearer, 'base64'));
            }
        }
        _.merge(clusterInformation, clusterData);
        clusterInformation.name = _.get(request, 'query.selector');
    }




    request.kubeManager = new KubeManager(clusterInformation);
    request.kubeManager.onAny(kubeEventHandler(request.account, request.user));
    next();
}

module.exports = {
    ensureNamespaceId,
    resolveNamespacesFromQuery,
    resolveQueryString,
    prepareKubeConfig
};

==> kube-integration-1.4.2.tgz: package/infra/middleware.js <==
'use strict';

const _                = require('lodash');
const Promise          = require('bluebird');
const logger           = require('cf-logs').Logger("codefresh:infra:middlewares");
const KubeManager      = require('./../lib/kube.manager');
const config           = require('./../config');
const MatchFilter      = require('./../server/helpers/filters').Match;
const kubeEventHandler = require('./kube.manager.event.handler');


function ensureNamespaceId(req, res, next) {
    const result = req.checkQuery('namespaceId', 'Query must have namespaceId').notEmpty();
    const errors = _.get(result, 'validationErrors', []);
    if (_.size(errors) > 0) {
        next(new Error(errors[0].msg));
    } else {
        next();
    }
    return;
}

/**
 * Resolve namespaces from query
 * If query have doesnt have any namespace then first fetch all namespaces related to the cluster
 * @param req
 * @param res
 * @param next
 */
function resolveNamespacesFromQuery(req, res, next) {
    const kube       = req.kubeManager;
    const namespaces = req.query.namespace;

    Promise.resolve()
        .then(() => {
            if (!namespaces) {
                return kube.getNamespaceController()
                    .get()
                    .map(ns => ns.getName());
            }

            if (_.isString(namespaces) && _.includes(namespaces, ',')) {
                return namespaces.split(',');
            }

            if (!_.isArray(namespaces)) {
                return [namespaces];
            }

            return namespaces;
        })
        .then((nss) => {
            req.namespaces = nss;
        })
        .done(next, next);
}

function resolveQueryString(req, res, next) { // jshint ignore:line
    const query   = _.omit(_.get(req, 'query', {}), ['namespace', 'selector', 'omit']);
    const keys    = _.keys(query);
    const filters = [];
    return Promise.map(keys, (key) => {
        const value = query[key];
        filters.push(new MatchFilter(key, value));
    })
        .then(() => {
            req.filters = filters;
        })
        .finally(next, next);
}

function prepareKubeConfig(request, response, next) {
    const clusterConf        = _.get(config, 'cluster');
    const clusterCreds       = _.get(clusterConf, 'credentials', {});
    const headers            = request.headers;
    const clusterInformation = {};
    if (clusterConf.host) {
        logger.info('Using cluster credentials from config file');
        logger.info('Using cluster credentials from config file');
        clusterInformation.credentials = {
            clusterCaCertificate: clusterCreds.clusterCaCertificate,
            serviceAccountToken: clusterCreds.token,

        };
        clusterInformation.host        = clusterConf.host;
        clusterInformation.protocol    = clusterConf.protocol
    } else {
        logger.info('Using cluster from headers');
        const clusterData = JSON.parse(headers['x-cluster-data-json']);
        const authType    = _.get(clusterData, 'type');
        // temporary here, should be handled more nicely
        if (authType) {
            if (authType === 'satcc') {
                _.set(clusterData, 'ca', Buffer.from(clusterData.ca, 'base64'));
                _.set(clusterData, 'cert', Buffer.from(clusterData.cert, 'base64'));
                _.set(clusterData, 'key', Buffer.from(clusterData.key, 'base64'));
                _.set(clusterData, 'auth.bearer', Buffer.from(clusterData.auth.bearer, 'base64'));
            } else if (authType === 'sat') {
                _.set(clusterData, 'ca', Buffer.from(clusterData.ca, 'base64'));
                _.set(clusterData, 'auth.bearer', Buffer.from(clusterData.auth.bearer, 'base64'));
            }
        }
        _.merge(clusterInformation, clusterData);
        clusterInformation.name = _.get(request, 'query.selector');
    }




    request.kubeManager = new KubeManager(clusterInformation);
    request.kubeManager.onAny(kubeEventHandler(request.account, request.user));
    next();
}

module.exports = {
    ensureNamespaceId,
    resolveNamespacesFromQuery,
    resolveQueryString,
    prepareKubeConfig
};
